#!/bin/sh

umount /cpusets 2> /dev/null
mount -t cpuset none /cpusets 2> /dev/null

cd /cpusets

# sd-1: Set exclusive on with no cpus
echo "sd-1: Set exclusive on with no cpus"
mkdir -p /cpusets/temp
cd /cpusets/temp
/bin/echo 0 > mems
/bin/echo 1 > cpu_exclusive
echo
read

# sd-2: Set exclusive off with no CPUs [exclusive previously on]
echo "sd-2: Set exclusive off with no CPUs [exclusive previously on]"
/bin/echo 0 > cpu_exclusive
echo
read

# sd-3: Add CPUs to a exclusive cpuset
echo "sd-3: Add CPUs to a exclusive cpuset"
/bin/echo 1 > cpu_exclusive
/bin/echo 0-3 > cpus
echo
read

# sd-4: Set exclusive on with exclusive already on
echo "sd-4: Set exclusive on with exclusive already on"
/bin/echo 1 > cpu_exclusive
echo
read

# sd-5: Add same set of CPUs as existing ones [exclusive on]
echo "sd-5: Add same set of CPUs as existing ones [exclusive on]"
/bin/echo 0-3 > cpus
echo
read

# sd-6: Set exclusive off with exclusive on
echo "sd-6: Set exclusive off with exclusive on"
/bin/echo 0 > cpu_exclusive
echo
read

# sd-7: Set exclusive off with exclusive already off
echo "sd-7: Set exclusive off with exclusive already off"
/bin/echo 0 > cpu_exclusive
echo
read

# sd-8: Remove CPUs from a exclusive cpuset
echo "sd-8: Remove CPUs from a exclusive cpuset"
/bin/echo 1 > cpu_exclusive
/bin/echo 0-1 > cpus
echo
read

# sd-9: Add CPUs to an exclusive cpuset
echo "sd-9: Add CPUs to an exclusive cpuset"
/bin/echo 0-3 > cpus
echo
read

# sd-10: rmdir exclusive cpuset
echo "sd-10: rmdir exclusive cpuset"
cd /cpusets
rmdir temp
echo
read

# sd-11: Set exclusive on to a cpuset with some CPUs
echo "sd-11: Set exclusive on to a cpuset with some CPUs"
mkdir -p /cpusets/temp
cd /cpusets/temp
/bin/echo 0-3 > cpus
/bin/echo 0 > mems
/bin/echo 1 > cpu_exclusive
echo
read

# sd-12: Set exclusive on with parent exclusive off
echo "sd-12: Set exclusive on with parent exclusive off"
/bin/echo 0 > cpu_exclusive
mkdir -p /cpusets/temp/temp1
cd /cpusets/temp/temp1
/bin/echo 2-3 > cpus
/bin/echo 0 > mems
/bin/echo 1 > cpu_exclusive
echo
read

# sd-13: Set exclusive on with parent exclusive on
echo "sd-13: Set exclusive on with parent exclusive on"
cd /cpusets/temp
/bin/echo 1 > cpu_exclusive
cd /cpusets/temp/temp1
/bin/echo 1 > cpu_exclusive
echo
read

# sd-14: Add CPUs to cpuset with exclusive children
echo "sd-14: Add CPUs to cpuset with exclusive children"
cd /cpusets/temp
/bin/echo 0-5 > cpus
echo
read

# sd-15: Remove CPUs from cpuset with exclusive children (illegal)
echo "sd-15: Remove CPUs from cpuset with exclusive children (illegal)"
cd /cpusets/temp
/bin/echo 0-1 > cpus
echo
read

# sd-16: Remove CPUs from cpuset with exclusive children (legal)
echo "sd-16: Remove CPUs from cpuset with exclusive children (legal)"
cd /cpusets/temp
/bin/echo 0-3 > cpus
echo
read

# cleanup
echo "cleanup"
cd /cpusets/temp
rmdir temp1
cd ..
rmdir temp
echo
read

echo "Enter to start stress test"
read
while [ true ];
do
	cd /cpusets
	rmdir wvs 2> /dev/null

	mkdir -p /cpusets/wvs
	cd /cpusets/wvs
	/bin/echo 0 > mems
	/bin/echo 2-7 > cpus
	/bin/echo 1 > cpu_exclusive
	/bin/echo 1 > cpu_exclusive

	mkdir -p /cpusets/wvs/tts
	cd /cpusets/wvs/tts
	/bin/echo 0 > mems
	/bin/echo 2-5 > cpus
	/bin/echo 1 > cpu_exclusive
	/bin/echo 1 > cpu_exclusive

	mkdir -p /cpusets/wvs/ll
	cd /cpusets/wvs/ll
	/bin/echo 0 > mems
	/bin/echo 6-7 > cpus
	/bin/echo 1 > cpu_exclusive
	/bin/echo 1 > cpu_exclusive

	mkdir -p /cpusets/wvs/tts/eng1
	cd /cpusets/wvs/tts/eng1
	/bin/echo 0 > mems
	/bin/echo 2-3 > cpus
	/bin/echo 1 > cpu_exclusive
	/bin/echo 1 > cpu_exclusive

	mkdir -p /cpusets/wvs/tts/eng2
	cd /cpusets/wvs/tts/eng2
	/bin/echo 0 > mems
	/bin/echo 4-5 > cpus
	/bin/echo 1 > cpu_exclusive
	/bin/echo 1 > cpu_exclusive

	cd /cpusets/wvs/tts
	rmdir eng1
	rmdir eng2

	cd /cpusets/wvs
	rmdir tts
	rmdir ll

	cd /cpusets
	rmdir wvs

	# temp tests

	cd /cpusets
	mkdir -p /cpusets/temp
	cd /cpusets/temp
	/bin/echo 0 > mems
	/bin/echo 1 > cpu_exclusive

	/bin/echo 0 > cpu_exclusive

	/bin/echo 1 > cpu_exclusive
	/bin/echo 0-3 > cpus

	/bin/echo 1 > cpu_exclusive

	/bin/echo 0-3 > cpus

	/bin/echo 0 > cpu_exclusive

	/bin/echo 0 > cpu_exclusive

	/bin/echo 1 > cpu_exclusive
	/bin/echo 0-1 > cpus

	/bin/echo 0-3 > cpus

	cd /cpusets
	rmdir temp

	mkdir -p /cpusets/temp
	cd /cpusets/temp
	/bin/echo 0-3 > cpus
	/bin/echo 0 > mems
	/bin/echo 1 > cpu_exclusive

	/bin/echo 0 > cpu_exclusive
	mkdir -p /cpusets/temp/temp1
	cd /cpusets/temp/temp1
	/bin/echo 2-3 > cpus
	/bin/echo 0 > mems
#	/bin/echo 1 > cpu_exclusive

	cd /cpusets/temp
	/bin/echo 1 > cpu_exclusive
	cd /cpusets/temp/temp1
	/bin/echo 1 > cpu_exclusive

	cd /cpusets/temp
	/bin/echo 0-5 > cpus

#	cd /cpusets/temp
#	/bin/echo 0-1 > cpus

	cd /cpusets/temp
	/bin/echo 0-3 > cpus

	cd /cpusets/temp
	rmdir temp1
	cd ..
	rmdir temp
done
